<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects. 
======================================================================= -->
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:xalan="http://xml.apache.org/xalan"
 xmlns:redirect="http://xml.apache.org/xalan/redirect"
 extension-element-prefixes="redirect">

<xsl:import href="xradar://stylesheets/radar/statics/graph/scatter-graph.xsl"/>

<xsl:template match="IntegratedAnalysis" mode="aggregatecomplexity-packagenumber-graph">
  <xsl:variable name="total-packages">    
    <xsl:value-of select="count(Packages/Package[Stats/source-classes-analyzed > 0])"/>      
  </xsl:variable>
  
  <xsl:variable name="aggregated-ccn">
    <xsl:value-of select="sum(Packages/Package/Stats/ccn)"/>
  </xsl:variable>
  
  <xsl:variable name="rtf-sorted-nodeset">
   <xsl:for-each select="Packages/Package[Stats/source-classes-analyzed > 0]/Stats">
    <xsl:sort select="ccn" order="descending" data-type="number"/>
    	<xsl:copy-of select="."/>
   </xsl:for-each>
  </xsl:variable>
    
   
  <xsl:variable name="rtf-point-nodeset">
   	<points>   		
		<xsl:for-each select="xalan:nodeset($rtf-sorted-nodeset)/*">    
			<xsl:variable name="source-statements">
				<xsl:if test="number(ccn)">
					<xsl:value-of select="ccn"/>
				</xsl:if>
				<xsl:if test="not(number(ccn))">
					0
				</xsl:if>
			</xsl:variable>
			<xsl:element name="point">
				<xsl:element name="x-coordinate">
					<xsl:copy-of select="count((.|preceding-sibling::Stats)) div $total-packages"/>
				</xsl:element>
				<xsl:element name="y-coordinate">
					<xsl:copy-of select="sum((.|preceding-sibling::Stats)/ccn) div $aggregated-ccn"/>
				</xsl:element>    		
			</xsl:element>
		</xsl:for-each>   
   </points>
  </xsl:variable>
  
    
  <xsl:variable name="rtf-graph-additions">    
	  
  </xsl:variable>
  
  <xsl:call-template name="scatter-graph">
  	<xsl:with-param name="text-x-axis">
  		Aggregated Cyclomatic Complexity
  	</xsl:with-param>
  	<xsl:with-param name="text-y-axis">
  		Packages
  	</xsl:with-param>
  	<xsl:with-param name="point-nodeset" select="$rtf-point-nodeset"/>
	<xsl:with-param name="graph-additions" select="$rtf-graph-additions"/>  	 	  		
	<xsl:with-param name="include-grid-lines" select="'true'"/>	
	<xsl:with-param name="include-pareto-lines" select="'true'"/>	
  </xsl:call-template> 
 

</xsl:template>

</xsl:stylesheet> 
