<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet version="1.0"
            	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
            	xmlns:xalan="http://xml.apache.org/xalan"
            	xmlns:lxslt="http://xml.apache.org/xslt"
                xmlns:redirect="http://xml.apache.org/xalan/redirect"
                extension-element-prefixes="redirect">

	<xsl:import href="scorecard/master-report-detail-scorecard-table.xsl"/>
	<xsl:import href="scorecard/master-report-detail-scorecard-architecture.xsl"/>
	<xsl:import href="scorecard/master-report-detail-scorecard-package-design.xsl"/>
	<xsl:import href="scorecard/master-report-detail-scorecard-code.xsl"/>
	<xsl:import href="scorecard/master-report-detail-scorecard-test.xsl"/>
	<xsl:import href="scorecard/master-report-detail-scorecard-source-control.xsl"/>

    <xsl:template match="Packages" mode="overview-subsystems">
        <xsl:param name="subsystem-name"/>
        <xsl:param name="path-to-root" select="'../'"/>

        <xsl:variable name="packages-element" select="current()"/>

        <xsl:variable name="subsystem-name-text">
            <xsl:choose>
                <xsl:when test="$subsystem-name = ''">Not Classified</xsl:when>
                <xsl:otherwise><xsl:value-of select="$subsystem-name"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <html>
          <head>
             <link rel="stylesheet" type="text/css" href="{$path-to-root}stylesheet.css"/>
          </head>
          <body>

             <xsl:call-template name="page-header">
                   <xsl:with-param name="page-name" select="'Subsystems'"/>
                   <xsl:with-param name="main-menu-page-name" select="'scorecard'"/>
                   <xsl:with-param name="path-to-root" select="$path-to-root"/>
                   <xsl:with-param name="subsystem-name" select="$subsystem-name-text"/>
               </xsl:call-template>

             <a name="{$subsystem-name}"><h3>Subsystem : <xsl:value-of select="$subsystem-name-text"/></h3></a>
            <xsl:choose>
            <xsl:when test="$subsystem-name=''">
                <p>
                    The following analysed packages have not been classified. Must be done in radar-config.xml:
                    <ul>
                        <xsl:for-each select="Package[(not(subsystem) or normalize-space(subsystem/@name)='') and not(error)]">
                            <li><xsl:value-of select="@name"/> -
                            <a><xsl:attribute name="href"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:attribute>
                            Go to package</a></li>
                        </xsl:for-each>
                        <xsl:if test="count(Package[(not(subsystem) or normalize-space(subsystem/@name)='') and not(error)]) = 0">
                            <li>No packages found. You have classified all packages.</li>
                        </xsl:if>
                    </ul>
                </p>
            </xsl:when>
            <xsl:otherwise>
            <table width="100%" class="scorecard">

				<tr>
                  <td valign="top">
                      <div valign="top" align="center">
                        <embed width="450" height="450" src="{$path-to-root}img/spider-graph-subsystem-{$subsystem-name}.svg" name="svgmap" pluginspage="http://www.adobe.com/svg/viewer/install/" type="image/svg+xml"></embed>
                     </div>
					  <table width="100%" style="border : 0;"><tr><td>
					      <b><xsl:value-of select="$radar-config-doc/radar-config/subsystems/subsystem[name = $subsystem-name]/description"/></b>
					  </td></tr></table>
                  </td>
                  <td>
		  			  <xsl:variable name="system-quality-report-filename"
					  		select="concat('file://',concat($docs-home,'/xml/reports/subsystem_quality_report_',normalize-space($subsystem-name),'.xml'))"/>
<!--
<xsl:message>
	FILENAME:<xsl:value-of select="$system-quality-report-filename"/>
</xsl:message>
-->
					  <xsl:call-template name="scorecard-table">
                        <xsl:with-param name="system-quality-report" select="document($system-quality-report-filename)"/>
                      </xsl:call-template>
                  </td>
                </tr>

            </table>
            <a name="{'dependencies'}"><h4>Dependencies</h4></a>
            <table width="100%" class="details">
                <xsl:call-template name="metric-header-dependencies"/>

                <xsl:for-each select="$packages-element/Package[(Stats) and (subsystem/@name=$subsystem-name)]">
                    <xsl:call-template name="subsystem-dependancies">
                        <xsl:with-param name="subsystem-name" select="@name"/>
                        <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                        <xsl:with-param name="packages-element" select="$packages-element"/>
                        <xsl:with-param name="package-element" select="current()"/>
                        <xsl:with-param name="single-package" select="'true'"/>
                    </xsl:call-template>
                </xsl:for-each>
            </table>

            <br/>
            <a name="{'design-metrics'}"><h4>Design Metrics</h4></a>
            <table width="100%" class="details">
                <xsl:call-template name="metric-header-package-design">
                    <xsl:with-param name="single-package" select="'true'"/>
                </xsl:call-template>


                <xsl:choose>
                    <xsl:when test="$subsystem-name = 'Not Classified'">
                        <xsl:for-each select="$packages-element/Package[(Stats) and (not(subsystem))]">
                            <xsl:call-template name="subsystem-design-metrics">
                                <xsl:with-param name="subsystem-name" select="@name"/>
                                <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                                <xsl:with-param name="single-package" select="'true'"/>
                                <xsl:with-param name="packages-with-cycles" select="count(Cycles)"/>
                                <xsl:with-param name="illegal-subsystem-dependencies" select="sum(Stats/dependancy-metrics/subsystem[@legal='false'])"/>
                                <xsl:with-param name="legal-subsystem-dependencies" select="sum(Stats/dependancy-metrics/subsystem[@legal='true'])"/>
								<xsl:with-param name="import-coupling" select="sum(Stats/coupling-metrics/import-coupling)"/>
								<xsl:with-param name="export-coupling" select="sum(Stats/coupling-metrics/export-coupling)"/>
                            </xsl:call-template>
                        </xsl:for-each>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="$packages-element/Package[(Stats) and (subsystem/@name=$subsystem-name)]">
                            <xsl:call-template name="subsystem-design-metrics">
                                <xsl:with-param name="subsystem-name" select="@name"/>
                                <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                                <xsl:with-param name="total-packages" select="count(Stats)"/>
                                <xsl:with-param name="distance" select="Stats/D"/>
                                <xsl:with-param name="efferent-couplings" select="Stats/Ce"/>
                                <xsl:with-param name="afferent-couplings" select="Stats/Ca"/>
                                <xsl:with-param name="single-package" select="'true'"/>
                                <xsl:with-param name="packages-with-cycles" select="count(Cycles)"/>
                                <xsl:with-param name="illegal-subsystem-dependencies" select="sum(Stats/dependancy-metrics/subsystem[@legal='false'])"/>
                                <xsl:with-param name="legal-subsystem-dependencies" select="sum(Stats/dependancy-metrics/subsystem[@legal='true'])"/>
								<xsl:with-param name="wmc" select="Stats/oo-metrics/wmc"/>
								<xsl:with-param name="dit" select="Stats/oo-metrics/dit"/>
								<xsl:with-param name="noc" select="Stats/oo-metrics/noc"/>
								<xsl:with-param name="cbo" select="Stats/oo-metrics/cbo"/>
								<xsl:with-param name="ca" select="Stats/oo-metrics/ca"/>
								<xsl:with-param name="rfc" select="Stats/oo-metrics/rfc"/>
								<xsl:with-param name="lcom" select="Stats/oo-metrics/lcom"/>
                            </xsl:call-template>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>

            </table>
            <br/>
            <a name="{'system-api'}"><h4>System API Metrics</h4></a>

            <table width="100%" class="details">
                <xsl:call-template name="metric-header-system-api"/>

                <xsl:choose>
                    <xsl:when test="$subsystem-name = 'Not Classified'">
                        <xsl:for-each select="$packages-element/Package[(Stats) and (not(subsystem))]">
                            <xsl:call-template name="subsystem-system-api-metrics">
                                <xsl:with-param name="subsystem-name" select="@name"/>
                                <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                                <xsl:with-param name="single-package" select="'true'"/>
                                <xsl:with-param name="api-packages" select="count(Stats[count(../Package[@public-api-package='true']) &gt; 0])"/>
                                <xsl:with-param name="api-classes" select="sum(Stats[count(../Package[@public-api-package='true']) &gt; 0]/TotalClasses)"/>
                                <xsl:with-param name="api-methods" select="sum(Stats[count(../Package[@public-api-package='true']) &gt; 0]/functions)"/>
                                <xsl:with-param name="api-source-statements" select="sum(Stats[count(../Package[@public-api-package='true']) &gt; 0]/ncss)"/>
                                <xsl:with-param name="api-import-couplings" select="sum(Stats[count(../Package[@public-api-package='true']) &gt; 0]/coupling-metrics/import-coupling)"/>
                                <xsl:with-param name="api-export-couplings" select="sum(Stats[count(../Package[@public-api-package='true']) &gt; 0]/coupling-metrics/export-coupling)"/>
                            </xsl:call-template>
                        </xsl:for-each>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="$packages-element/Package[(Stats) and (subsystem/@name=$subsystem-name)]">
                            <xsl:call-template name="subsystem-system-api-metrics">
                                <xsl:with-param name="subsystem-name" select="@name"/>
                                <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                                <xsl:with-param name="single-package" select="'true'"/>
                                <xsl:with-param name="api-packages" select="count(Stats[parent::node()[@public-api-package='true']])"/>
                                <xsl:with-param name="api-classes" select="sum(Stats[parent::node()[@public-api-package='true']]/TotalClasses)"/>
                                <xsl:with-param name="api-methods" select="sum(Stats[parent::node()[@public-api-package='true']]/functions)"/>
                                <xsl:with-param name="api-source-statements" select="sum(Stats[parent::node()[@public-api-package='true']]/ncss)"/>
                                <xsl:with-param name="api-import-couplings" select="sum(Stats[parent::node()[@public-api-package='true']]/coupling-metrics/import-coupling)"/>
                                <xsl:with-param name="api-export-couplings" select="sum(Stats[parent::node()[@public-api-package='true']]/coupling-metrics/export-coupling)"/>
                            </xsl:call-template>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>

            </table>
            <br/>
            <a name="{'code-metrics'}"><h4>Code Metrics</h4></a>

            <table width="100%" class="details">
                <xsl:call-template name="metric-header-code">
                    <xsl:with-param name="single-package" select="'true'"/>
                </xsl:call-template>

                <xsl:choose>
                    <xsl:when test="$subsystem-name = 'Not Classified'">
                        <xsl:for-each select="$packages-element/Package[(Stats) and (not(subsystem))]">
                            <xsl:call-template name="subsystem-code-metrics">
                                <xsl:with-param name="subsystem-name" select="@name"/>
                                <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                                <xsl:with-param name="single-package" select="'true'"/>
                                <xsl:with-param name="source-statements-in-subsystem" select="Stats/ncss"/>
                                <xsl:with-param name="methods-in-subsystem" select="Stats/functions"/>
                                <xsl:with-param name="cyclomatic-complexity-in-subsystem" select="Stats/ccn"/>
                                <xsl:with-param name="total-packages" select="Stats"/>
                                <xsl:with-param name="total-classes" select="Stats/TotalClasses"/>
                                <xsl:with-param name="bc-classes" select="Stats/business-critical-classes"/>
                                <xsl:with-param name="violations" select="Stats/code-violations"/>
                                <xsl:with-param name="style-errors" select="Stats/style-errors"/>
                                <xsl:with-param name="duplicated-tokens" select="sum(Stats/duplication-metrics/tokens)"/>
                            </xsl:call-template>
                        </xsl:for-each>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="$packages-element/Package[(Stats) and (subsystem/@name=$subsystem-name)]">
                            <xsl:call-template name="subsystem-code-metrics">
                                <xsl:with-param name="subsystem-name" select="@name"/>
                                <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                                <xsl:with-param name="single-package" select="'true'"/>
                                <xsl:with-param name="source-statements-in-subsystem" select="Stats/ncss"/>
                                <xsl:with-param name="methods-in-subsystem" select="Stats/functions"/>
                                <xsl:with-param name="cyclomatic-complexity-in-subsystem" select="Stats/ccn"/>
                                <xsl:with-param name="total-packages" select="Stats"/>
                                <xsl:with-param name="total-classes" select="Stats/TotalClasses"/>
                                <xsl:with-param name="bc-classes" select="Stats/business-critical-classes"/>
                                <xsl:with-param name="violations" select="Stats/code-violations"/>
                                <xsl:with-param name="style-errors" select="Stats/style-errors"/>
                                <xsl:with-param name="duplicated-tokens" select="sum(Stats/duplication-metrics/tokens)"/>
                            </xsl:call-template>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>

            </table>
            <br/>
            <a name="test-metrics"><h4>Test Metrics</h4></a>
            <table width="100%" class="details">
                <xsl:call-template name="metric-header-test"/>

                <xsl:for-each select="$packages-element/Package[(Stats) and (subsystem/@name=$subsystem-name)]">
                    <xsl:call-template name="subsystem-test-detail">
                        <xsl:with-param name="subsystem-name" select="@name"/>
                        <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                        <xsl:with-param name="suites" select="sum(Stats/test-metrics/testsuites)"/>
                        <xsl:with-param name="tests" select="sum(Stats/test-metrics[tests and not(tests ='NaN') and not(tests ='')]/tests)"/>
                        <xsl:with-param name="errors" select="sum(Stats/test-metrics/errors)"/>
                        <xsl:with-param name="time" select="sum(Stats/test-metrics/time)"/>
                        <xsl:with-param name="line-coverage" select="sum(Stats/test-metrics[not(source-statements-covered ='NaN') and not(source-statements-covered ='')]/line-coverage)"/>
                        <xsl:with-param name="source-statements" select="sum(Stats/ncss)"/>
                    </xsl:call-template>
                </xsl:for-each>
            </table>
            <br/>
            <a name="source-control-metrics"><h4>Source Control Metrics</h4></a>
            <table width="100%" class="details">
                <xsl:call-template name="metric-header-source-control"/>

                <xsl:for-each select="$packages-element/Package[(Stats) and (subsystem/@name=$subsystem-name)]">
                    <xsl:call-template name="subsystem-source-control-metrics">
                        <xsl:with-param name="subsystem-name" select="@name"/>
                        <xsl:with-param name="subsystem-link"><xsl:call-template name="package-url">
                                        <xsl:with-param name="package-name" select="@name"/>
                                        <xsl:with-param name="path-to-root" select="$path-to-root"/>
                                      </xsl:call-template></xsl:with-param>
                        <xsl:with-param name="change-activity" select="sum(Stats/source-control-metrics/change-activity)"/>
                        <xsl:with-param name="error-activity" select="sum(Stats/source-control-metrics/error-activity)"/>
                        <xsl:with-param name="change-classes" select="sum(Stats/source-control-metrics/change-classes)"/>
                        <xsl:with-param name="error-classes" select="sum(Stats/source-control-metrics/error-classes)"/>
                    </xsl:call-template>
                </xsl:for-each>
            </table>
            <br/>
            <hr size="1"/>
            </xsl:otherwise>
            </xsl:choose>
          </body>
       </html>

    </xsl:template>

</xsl:stylesheet>
